<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
    append-to-body
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      @keyup.enter.native="dataFormSubmit()"
      label-width="80px"
      class="l-mes"
      :disabled="!editable"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="零件" prop="partId">
            <el-input
              v-model="dataForm.partNo"
              placeholder="零件"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="零件批号" prop="partBatchNo">
            <el-input
              v-model="dataForm.partBatchNo"
              placeholder="零件批号"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="库位号" prop="locationId">
            <el-input
              v-model="dataForm.locNo"
              placeholder="库位号"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="库存数量" prop="locQty">
            <el-input
              v-model="dataForm.locQty"
              placeholder="库存数量"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="单位" prop="unit">
            <el-input
              v-model="dataForm.unit"
              placeholder="单位"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="盘点数量" prop="chkQty">
            <el-input
              v-model="dataForm.chkQty"
              placeholder="盘点数量"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="盘点差异数量" prop="chkDiffQty">
            <el-input
              v-model="dataForm.chkDiffQty"
              placeholder="盘点差异数量"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button type="primary" @click="dataFormSubmit()">确定</el-button>
    </span>
  </el-dialog>
</template>

<script>
import {
  getObjCheckDetail,
  addObjCheckDetail,
  putObjCheckDetail
} from '@/api/warehouse/checkmain'

export default {
  data() {
    return {
      checkStatus: null,
      visible: false,
      dataForm: {
        id: 0,
        warehouseCheckId: '',
        partId: '',
        partBatchNo: '',
        locationId: '',
        locQty: '',
        unit: '',
        chkQty: '',
        chkStatus: '',
        chkDiffQty: ''
      },
      dataRule: {}
    }
  },
  computed: {
    editable: function() {
      if (!this.dataForm.id) {
        return true
      }
      if (this.dataForm.id && this.checkStatus == '未下发') {
        return true
      }
      return false
    }
  },
  methods: {
    init(id, status) {
      this.dataForm.id = id || 0
      this.visible = true
      this.checkStatus = status
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObjCheckDetail(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObjCheckDetail(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.$emit('refreshDataList')
            })
          } else {
            addObjCheckDetail(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.$emit('refreshDataList')
            })
          }
        }
      })
    }
  }
}
</script>
